export const getComponentFromProp = (instance, prop) => {
  const slots = instance.$slots
  return slots[prop] || instance.$props[prop]
}

/**
 * Check if an element has a class
 * @param {HTMLElement} elm
 * @param {string} cls
 * @returns {boolean}
 */
export function hasClass(ele, cls) {
  return !!ele.className.match(new RegExp('(\\s|^)' + cls + '(\\s|$)'))
}

/**
 * Add class to element
 * @param {HTMLElement} elm
 * @param {string} cls
 */
export function addClass(ele, cls) {
  if (!hasClass(ele, cls)) ele.className += ' ' + cls
}

/**
 * Remove class from element
 * @param {HTMLElement} elm
 * @param {string} cls
 */
export function removeClass(ele, cls) {
  if (hasClass(ele, cls)) {
    const reg = new RegExp('(\\s|^)' + cls + '(\\s|$)')
    ele.className = ele.className.replace(reg, ' ')
  }
}

export function toggleTheme(scopeName) {
  let styleLink = document.getElementById('theme-link-tag')
  if (styleLink) {
    // 假如存在id为theme-link-tag 的link标签，直接修改其href
    styleLink.href = `/${scopeName}.css`
    document.documentElement.className = scopeName
  } else {
    // 不存在的话，则新建一个
    styleLink = document.createElement('link')
    styleLink.type = 'text/css'
    styleLink.rel = 'stylesheet'
    styleLink.id = 'theme-link-tag'
    styleLink.href = `/${scopeName}.css`
    document.documentElement.className = scopeName
    document.head.append(styleLink)
  }
}
