import { Cascader } from 'element-ui'
import { omit } from 'lodash'

const CascaderProps = {
  ...omit(Cascader.props, 'options'),
  options: {
    type: [Array, Function],
    default: () => [],
  },
  query: {
    type: [Object, String],
    default: () => ({}),
  },
}

export default {
  name: 'ZkCascader',
  model: {
    prop: 'value',
    event: 'change',
  },
  props: CascaderProps,
  data() {
    return {
      data: [],
    }
  },
  watch: {
    options(val) {
      if (Array.isArray(val)) {
        this.data = val
      }
    },
  },
  async created() {
    if (typeof this.options === 'function') {
      this.data = await this.options(this.query)
    } else {
      this.data = this.options
    }
  },
  mounted() {
    this.$nextTick(() => {
      const functions = Cascader.methods
      for (const item in functions) {
        this[item] = function () {
          this.$refs.cascader[item].apply(this, arguments)
        }
      }
    })
  },
  render() {
    const { data, value } = this
    const filteredProps = Object.keys(Cascader.props).reduce((prev, cur) => {
      if (cur === 'options') {
        prev[cur] = data
      } else {
        prev[cur] = this[cur]
      }
      return prev
    }, {})
    return <Cascader {...{ props: filteredProps, on: this.$listeners }} ref='cascader' scopedSlots={this.$scopedSlots} value={value}></Cascader>
  },
}
