import { CheckboxGroup, Checkbox } from 'element-ui'
import { omit } from 'lodash'

const groupProps = {
  ...Checkbox.props,
  ...CheckboxGroup.props,
  options: {
    type: [Array, Function],
    default: () => [],
  },
  query: {
    type: [Object, String],
    default: () => ({}),
  },
  value: {
    type: Array,
    default: () => [],
  },
}

export default {
  name: 'ZkCheckboxGroup',
  model: {
    prop: 'value',
    event: 'change',
  },
  props: groupProps,
  data() {
    return {
      data: [],
    }
  },
  watch: {
    options(val) {
      if (Array.isArray(val)) {
        this.data = val
      }
    },
  },
  async created() {
    if (typeof this.options === 'function') {
      this.data = await this.options(this.query)
    } else {
      this.data = this.options
    }
  },
  render() {
    const { data, value } = this
    const filteredProps = Object.keys(CheckboxGroup.props).reduce((prev, cur) => {
      prev[cur] = this[cur]
      return prev
    }, {})
    return data.length ? (
      <CheckboxGroup
        {...{ attrs: filteredProps, on: this.$listeners }}
        value={value}
        onInput={(val) => {
          this.$emit('input', val)
        }}>
        {data.map((option, index) => {
          let checkboxProps = Object.keys(Checkbox.props).reduce((prev, cur) => {
            prev[cur] = this[cur]
            return prev
          }, {})
          // 剔除和group重复的属性
          checkboxProps = omit(checkboxProps, ['value', 'disabled'])
          return (
            <Checkbox {...{ attrs: checkboxProps }} label={option.value} key={option.label + index} disabled={option.disabled}>
              {option.label}
            </Checkbox>
          )
        })}
      </CheckboxGroup>
    ) : null
  },
}
