import { Form, Row } from 'element-ui'
import { cloneDeep, omit, pick } from 'lodash'
import FormItem from './FormItem'

// ZkForm在ElForm原有props基础上剔除model属性并扩充组件自身的props
const formProps = {
  ...omit(Form.props, 'model'),
  /**
   * @description: 行属性
   * @param {*}
   * @return {*}
   */
  rowProps: {
    type: Object,
    default: () => ({}),
  },
  /**
   * @description: 表单元素集合
   * @param {*}
   * @return {*}
   */
  items: {
    type: Array,
    require: true,
    /**
     * @description: 表单初始值
     * @param {*}
     * @return {*}
     */
  },
  initialValues: {
    type: Object,
    default: () => ({}),
  },
}

export default {
  name: 'ZkForm',
  components: {
    Form,
    Row,
  },
  provide() {
    return {
      form: this,
    }
  },
  props: formProps,
  data() {
    return {
      /**
       * @description: 深拷贝初始值，避免污染源数据
       * @param {*}
       * @return {*}
       */
      formModel: cloneDeep(this.initialValues),
    }
  },
  mounted() {
    this.$nextTick(() => {
      const functions = Form.methods
      for (const item in functions) {
        this[item] = function () {
          this.$refs.form[item].apply(this, arguments)
        }
      }
    })
  },
  methods: {
    getFormModel() {
      return cloneDeep(this.formModel)
    },
  },
  render() {
    return (
      <Form
        ref='form'
        {...{
          props: {
            // 只传入ELForm的props，
            ...pick(this.$props, Object.keys(Form.props)),
            model: this.formModel,
          },
          class: 'zk-form',
        }}>
        {/* 遍历表单元素填充相应的组件 */}
        <Row {...{ props: { ...this.rowProps } }}>
          {this.items.map((item) => (
            <FormItem
              key={item.field}
              formModel={this.formModel}
              item={item}
              onChange={(val) => {
                this.$set(this.formModel, item.field, val)
                this.$forceUpdate()
              }}
            />
          ))}
          {this.$slots.default}
        </Row>
      </Form>
    )
  },
}
