import { Breadcrumb, BreadcrumbItem } from 'element-ui'
import './index.scss'

const ElBreadcrumb = Breadcrumb
const ElBreadcrumbItem = BreadcrumbItem

export default {
  name: 'ZkHeader',
  inject: ['layout'],
  props: {
    rightContentRender: {
      type: Array,
      default: () => [],
    },
  },
  render() {
    const {
      $route,
      rightContentRender,
      layout: { sideWidth, collapsed },
    } = this
    // 处理面包屑需要显示的数据
    const routes = $route.matched
      .concat()
      .map((route) => ({
        path: route.path,
        breadcrumbName: route.meta.title,
        hidden: route.meta.hidden,
      }))
      .filter((route) => !!route.breadcrumbName)
    const cls = ['header']
    return (
      <header
        class={cls}
        style={{
          left: collapsed ? '76px' : sideWidth,
        }}>
        {/* 左边固定面包屑 */}
        <div class='header-left'>
          <ElBreadcrumb class='breadcrumb-wrapper' separator='>'>
            {routes.map((route, index) => (
              <ElBreadcrumbItem key={route.breadcrumbName + index} to={{ path: route.path || '/' }}>
                {route.breadcrumbName}
              </ElBreadcrumbItem>
            ))}
          </ElBreadcrumb>
        </div>
        {/* 头部右边内容 */}
        {rightContentRender && <div class='header-right'>{rightContentRender}</div>}
      </header>
    )
  },
}
