import { Container, Main } from 'element-ui'
import Emitter from '../_util/emitter'
import { getComponentFromProp } from '../_util/util'
import ZkHeader from './header'
import ZkSideMenu from './side-bar'
import PageWrapper from './page-wrapper'
import './layout.scss'

const ElContainer = Container
const ElMain = Main

const BasicProps = {
  sideWidth: {
    type: String,
    default: '237px',
  },
  menuHeaderRender: {
    type: Boolean,
    default: true,
  },
  collapsed: {
    type: Boolean,
    default: false,
  },
  logo: [String, Function, Object],
  title: [String, Boolean],
  theme: {
    type: String,
    default: 'light',
  },
  navMode: {
    type: String,
    default: 'side-bar',
  },
  primaryColor: {
    type: String,
    default: '#409EFF',
  },
  menus: {
    type: Array,
    require: true,
    default: () => [],
  },
  fixedHeader: {
    type: Boolean,
    default: true,
  },
  breadcrumb: {
    type: Boolean,
    default: true,
  },
}

export default {
  name: 'ZkLayout',
  componentName: 'ZkLayout',
  mixins: [Emitter],
  provide() {
    return {
      layout: this,
    }
  },
  props: BasicProps,
  mounted() {
    this.$on('handle-collapse', (collapsed) => {
      this.$emit('toggle-collapse', collapsed)
    })
  },
  render() {
    const { sideWidth, fixedHeader, collapsed, navMode } = this
    const menuHeaderRender = getComponentFromProp(this, 'menuHeaderRender')
    const leftContentRender = getComponentFromProp(this, 'leftContentRender')
    const rightContentRender = getComponentFromProp(this, 'rightContentRender')
    const cls = ['base-wrapper']
    return (
      <ElContainer direction='horizontal' class={cls}>
        {/* 菜单栏 */}
        <ZkSideMenu menuHeaderRender={menuHeaderRender} rightContentRender={rightContentRender} />
        {/* 右侧内容区 */}
        <ElContainer
          class='layout-wrappper'
          style={{
            paddingLeft: collapsed ? '76px' : sideWidth || BasicProps.sideWidth.default,
          }}>
          <ElMain class='layout-main'>
            {/* 头部 */}
            <ZkHeader leftContentRender={leftContentRender} rightContentRender={rightContentRender} />
            {/* 内容 */}
            <div class='content-wrapper'>
              <PageWrapper />
            </div>
          </ElMain>
        </ElContainer>
      </ElContainer>
    )
  },
}
