import { Aside } from 'element-ui'
import ZkMenu from './Menu'
import Emitter from '../../_util/emitter'
import '../layout.scss'

const ElAside = Aside

const renderMenuHeader = (h, props) => {
  const { logo, title, menuHeaderRender, collapsed } = props
  if (!menuHeaderRender) return null
  let logoDom
  switch (typeof logo) {
    case 'function':
      logoDom = logo()
      break
    case 'string':
      logoDom = <iconpark-icon name={logo} size={40} />
      break
    case 'object':
      if (logo instanceof h('span', '').constructor) {
        logoDom = logo
      } else {
        logoDom = null
        console.error('logo should be a VNode object')
      }
      break
    default:
      logoDom = null
      break
  }
  const titleDom = collapsed ? null : (title && <h1>{title}</h1>) || null
  return logoDom || titleDom ? (
    <div class='menu-header-wrapper'>
      {logoDom}
      {titleDom}
    </div>
  ) : (
    menuHeaderRender
  )
}

const renderFooter = (h, collapsed) => {
  const iconName = collapsed ? 'zhankai' : 'shouqi'
  return <iconpark-icon name={iconName}></iconpark-icon>
}

const SideMenu = {
  name: 'ZkSideMenu',
  mixins: [Emitter],
  props: {
    menuHeaderRender: [Boolean, Array],
  },
  inject: ['layout'],
  data() {
    return {
      menuBackgroundColor: '',
    }
  },
  render(h) {
    const {
      menuHeaderRender,
      layout: { logo, title, theme, collapsed, sideWidth },
    } = this
    const cls = ['side-menu']
    if (collapsed) {
      cls.push('side-menu-collapsed')
    }
    cls.push(theme)
    const headerDom = renderMenuHeader(h, {
      logo,
      title,
      menuHeaderRender,
      collapsed,
    })
    const footerDom = renderFooter(h, collapsed)
    return (
      <ElAside class={cls} width={collapsed ? '76px' : sideWidth}>
        {headerDom && <div class='menu-header'>{headerDom}</div>}
        <ZkMenu />
        {footerDom && (
          <div
            class='menu-footer'
            onClick={() => {
              this.dispatch('ZkLayout', 'handle-collapse', !collapsed)
            }}>
            {footerDom}
          </div>
        )}
      </ElAside>
    )
  },
}

export default SideMenu
