import { RadioGroup, Radio, RadioButton } from 'element-ui'
import { omit } from 'lodash'

const groupProps = {
  ...Radio.props,
  ...RadioGroup.props,
  options: {
    type: [Array, Function],
    default: () => [],
  },
  query: {
    type: [Object, String],
    default: () => ({}),
  },
  value: {
    type: [String, Number, Boolean],
    default: '',
  },
  type: {
    type: String,
    default: '',
  },
}

export default {
  name: 'ZkRadioGroup',
  model: {
    prop: 'value',
    event: 'change',
  },
  props: groupProps,
  data() {
    return {
      data: [],
    }
  },
  watch: {
    options(val) {
      if (Array.isArray(val)) {
        this.data = val
      }
    },
  },
  async created() {
    if (typeof this.options === 'function') {
      this.data = await this.options(this.query)
    } else {
      this.data = this.options
    }
  },
  render() {
    const { data, value, type } = this
    const filteredProps = Object.keys(RadioGroup.props).reduce((prev, cur) => {
      prev[cur] = this[cur]
      return prev
    }, {})
    return data.length ? (
      <RadioGroup
        {...{ attrs: filteredProps, on: this.$listeners }}
        value={value}
        onInput={(val) => {
          this.$emit('input', val)
        }}>
        {data.map((option, index) => {
          let radioProps = Object.keys(Radio.props).reduce((prev, cur) => {
            prev[cur] = this[cur]
            return prev
          }, {})
          // 剔除和group重复的属性
          radioProps = omit(radioProps, ['value', 'disabled'])
          return type === 'button' ? (
            <RadioButton {...{ attrs: radioProps }} label={option.value} key={option.label + index} disabled={option.disabled}>
              {' '}
              {option.label}
            </RadioButton>
          ) : (
            <Radio {...{ attrs: radioProps }} label={option.value} key={option.label + index} disabled={option.disabled}>
              {' '}
              {option.label}
            </Radio>
          )
        })}
      </RadioGroup>
    ) : null
  },
}
