import Editor from '@tinymce/tinymce-vue'
import { merge } from 'lodash'

const defaultOptions = {
  language: `zh_CN`,
  content_style: 'p, div {font-size: 14px; border:0px ; padding: 0px; line-height: 1}',
  font_formats:
    '微软雅黑=Microsoft YaHei,Helvetica Neue,PingFang SC,sans-serif;苹果苹方=PingFang SC,Microsoft YaHei,sans-serif;宋体=simsun,serif;Andale Mono=andale mono,times;Arial=arial,helvetica,sans-serif;Arial Black=arial black,avant garde;Book Antiqua=book antiqua,palatino;Comic Sans MS=comic sans ms,sans-serif;Courier New=courier new,courier;Georgia=georgia,palatino;Helvetica=helvetica;Impact=impact,chicago;Symbol=symbol;Tahoma=tahoma,arial,helvetica,sans-serif;Terminal=terminal,monaco;Times New Roman=times new roman,times;Trebuchet MS=trebuchet ms,geneva;Verdana=verdana,geneva;Webdings=webdings;Wingdings=wingdings,zapf dingbats',
  height: 400,
  statusbar: false,
  menubar: false,
  branding: false,
  toolbar_mode: 'wrap',
  plugins: ['advlist autolink lists link image charmap print preview anchor', 'searchreplace visualblocks code fullscreen', 'insertdatetime media table paste code help wordcount '],
  toolbar: 'undo redo  searchreplace  bold italic underline strikethrough  backcolor forecolor  fontselect fontsizeselect formatselect lineheight  alignleft aligncenter alignright alignjustify outdent indent  hr bullist numlist  link image charmap  anchor pagebreak insertdatetime media table emoticons  removeformat  blockquote code  fullscreen preview customBtn',
}

export default {
  name: 'ZkRichText',
  model: {
    prop: 'content',
    event: 'change',
  },
  props: {
    content: {
      type: String,
      default: '',
    },
    init: {
      type: Object,
      default: () => ({}),
    },
    apiKey: {
      type: String,
      default: 'pk8d8r92i87tdk0hjlmewyb2y2tx7dlpj5x46paz9ekbbn0q',
    },
  },
  data() {
    return {
      options: merge(defaultOptions, this.init),
    }
  },
  render() {
    return (
      <Editor
        apiKey={this.apiKey}
        init={this.options}
        value={this.content}
        onOnChange={(_, editor) => {
          this.$emit('change', editor.getContent())
        }}
        onOnUndo={(_, editor) => {
          this.$emit('change', editor.getContent())
        }}
        onOnRedo={(_, editor) => {
          this.$emit('change', editor.getContent())
        }}
      />
    )
  },
}
