import { Select, OptionGroup, Option, Empty } from 'element-ui'
import Spin from '../spin'

/**
 * @description: 将原对象的key值替换为新的key值
 * @param {*} obj 源对象
 * @param {*} keyMap key值映射关系
 * @return {*}
 */
const mapObjectKey = (obj, keyMap) => {
  const newO = Object.keys(keyMap).reduce((newObj, key) => {
    newObj[key] = obj[keyMap[key]]
    return newObj
  }, {})
  return { ...obj, ...newO }
}

const selectProps = {
  ...Select.props,
  options: {
    type: [Array, Function],
    default: () => [],
  },
  /**
   * @description: 获取远程数据时的查询条件
   * @param {*}
   * @return {*}
   */
  query: {
    type: [Object, String],
    default: () => ({}),
  },
  labelProps: {
    type: Object,
    default: () => ({
      label: 'label',
      value: 'value',
    }),
  },
  grouping: {
    type: Boolean,
    default: false,
  },
  value: {
    type: [String, Number, Boolean, Array],
    default: '',
  },
}

export default {
  name: 'ZkSelect',
  components: { Select, Option, OptionGroup, Spin, Empty },
  model: {
    prop: 'value',
    event: 'change',
  },
  props: selectProps,
  data() {
    return {
      dataList: [],
      // 正在加载数据的标记
      loadingRequest: false,
    }
  },
  watch: {
    options: {
      handler(val) {
        if (Array.isArray(val)) {
          this.dataList = val.map((ele) => mapObjectKey(ele, this.labelProps))
        }
      },
    },
  },
  created() {
    if (typeof this.options === 'function') {
      this.loadingRequest = true
      this.options(this.query).then((res) => {
        this.dataList = res.map((ele) => mapObjectKey(ele, this.labelProps))
        this.loadingRequest = false
      })
    } else {
      this.dataList = this.options.map((ele) => mapObjectKey(ele, this.labelProps))
    }
  },
  render() {
    const { dataList, grouping, value } = this
    const filteredProps = Object.keys(Select.props).reduce((prev, cur) => {
      prev[cur] = this[cur]
      return prev
    }, {})
    return (
      <Select
        {...{ props: filteredProps, on: this.$listeners }}
        value={value}
        onChange={(val) => {
          this.$emit('change', val)
        }}>
        {this.$slots.prefix}
        {this.loadingRequest ? <Spin slot='empty' size={this.size} tip={this.loadingText || 'loading...'}></Spin> : this.$slots.empty || <Empty slot='empty' imageSize={50} description='暂无数据'></Empty>}
        {grouping
          ? dataList.map((option, index) => (
              <OptionGroup key={option.label + index} label={option.label} value={option.value} disabled={option.disabled}>
                {option.options.map((op) => (
                  <ElOption key={op.value} label={op.label} value={op.value} disabled={op.disabled}>
                    {this.$scopedSlots.option && this.$scopedSlots.option(op)}
                  </ElOption>
                ))}
              </OptionGroup>
            ))
          : dataList.map((option) => (
              <ElOption key={option.value} label={option.label} value={option.value} disabled={option.disabled}>
                {this.$scopedSlots.option && this.$scopedSlots.option(option)}
              </ElOption>
            ))}
      </Select>
    )
  },
}
