import { Dropdown, DropdownMenu, DropdownItem, Divider, Button } from 'element-ui'
import { omit, pick } from 'lodash'
import { Fragment } from 'vue-fragment'

export default {
  name: 'ZkAction',
  components: {
    Dropdown,
    DropdownMenu,
    DropdownItem,
    Divider,
    Button,
  },
  props: {
    column: {
      type: Object,
      default: () => ({}),
    },
    actions: {
      type: Array,
      default: () => [],
    },
  },
  render() {
    const { actions, column } = this
    return actions.length > 3 ? (
      <div>
        <Button
          {...omit(actions[0], 'onClick')}
          {...{ props: pick(actions[0], Object.keys(Button.props)) }}
          type='text'
          onClick={() => {
            actions[0].onClick && actions[0].onClick(column)
          }}>
          {actions[0].label}
        </Button>
        <Divider direction='vertical' />
        <Button
          {...omit(actions[1], 'onClick')}
          {...{ props: pick(actions[1], Object.keys(Button.props)) }}
          type='text'
          onClick={() => {
            actions[1].onClick && actions[1].onClick(column)
          }}>
          {actions[1].label}
        </Button>
        <Divider direction='vertical' />
        <Dropdown>
          <Button type='text'>更多</Button>
          <DropdownMenu>
            {actions.slice(2).map((item) => (
              <DropdownItem key={item.label}>
                <Button
                  {...omit(item, 'onClick')}
                  type='text'
                  onClick={() => {
                    item.onClick && item.onClick(column)
                  }}>
                  {item.label}
                </Button>
              </DropdownItem>
            ))}
          </DropdownMenu>
        </Dropdown>
      </div>
    ) : (
      <div>
        {actions.map((item, index) => (
          <Fragment>
            <Button
              {...omit(item, 'onClick')}
              key={item.label + index}
              type='text'
              onClick={() => {
                item.onClick && item.onClick(column)
              }}>
              {item.label}
            </Button>
            {index !== actions.length - 1 && <Divider direction='vertical' />}
          </Fragment>
        ))}
      </div>
    )
  },
}
