import Form from '../../form'
import { Button, FormItem } from 'element-ui'
import './index.scss'

export default {
  props: {
    columns: {
      type: Array,
      required: true,
    },
  },
  data() {
    return {
      collapsed: true,
    }
  },
  computed: {
    formItems() {
      return this.columns
        .filter((column) => {
          return column.prop !== '$$action' && column.formItemProps
        })
        .map((column) => ({
          field: column.prop,
          label: column.label,
          colProps: {
            span: 6,
          },
          ...column.formItemProps,
        }))
    },
  },
  methods: {
    handleCollapse() {
      this.collapsed = !this.collapsed
    },
    handleReset() {
      this.$refs.form.resetFields()
      this.$emit('reset')
    },
    handleQuery() {
      this.$emit('query', this.$refs.form.formModel)
    },
  },
  render() {
    return this.formItems.length > 0 ? (
      <Form ref='form' inline items={this.formItems.slice(0, this.collapsed ? 3 : this.formItems.length)}>
        <FormItem class='query-item'>
          <div>
            <Button type='primary' onClick={this.handleQuery}>
              查询
            </Button>
            <Button onClick={this.handleReset}>重置</Button>
            {this.formItems.length > 3 && (
              <Button type='text' class='fold' onClick={this.handleCollapse}>
                <span>{this.collapsed ? '展开' : '收起'}</span>
                <i class='el-icon-arrow-down'></i>
              </Button>
            )}
          </div>
        </FormItem>
      </Form>
    ) : null
  },
}
