import { Tooltip, Popover, Checkbox, Button } from 'element-ui'
import Emitter from '../../_util/emitter'
import { cloneDeep } from 'lodash'
export default {
  mixins: [Emitter],
  inject: ['columns', 'table'],
  data() {
    return {
      allChecked: false,
      isIndeterminate: true,
      cols: [],
    }
  },
  watch: {
    columns: {
      handler() {
        this.initialize()
      },
      immediate: true,
    },
  },
  methods: {
    initialize() {
      this.cols = cloneDeep(this.columns)
      this.allChecked = !this.columns.some((col) => col.hideInTable)
      const num = this.columns.filter((col) => !col.hideInTable).length
      this.isIndeterminate = num > 0 && num < this.columns.length
    },
    handleCheckAllChange(val) {
      this.cols.forEach((column, index) => {
        this.dispatch('ZkTable', 'change-hide', { hide: !val, index: index })
        column.hideInTable = !val
      })
      this.isIndeterminate = false
    },
    reset() {
      this.initialize()
      this.columns.forEach(() => {
        this.dispatch('ZkTable', 'reset')
      })
    },
    // 初始化排序
    initialDraggable() {
      this.$nextTick(async () => {
        const el = this.$refs.sortDiv
        const sortable = (await import('sortablejs')).default
        sortable.create(el, {
          animation: 500,
          delay: 400,
          delayOnTouchOnly: true,
          handle: '.drag-out',
          onEnd: (e) => {
            const { oldIndex, newIndex } = e
            this.cols.splice(newIndex, 0, this.cols.splice(oldIndex, 1)[0])
            this.dispatch('ZkTable', 'change-sort', { newIndex, oldIndex })
          },
        })
      })
    },
  },
  render() {
    return (
      <Popover trigger='click' onShow={this.initialDraggable}>
        <div>
          <div class='popover-title'>
            <Checkbox indeterminate={this.isIndeterminate} v-model={this.allChecked} onChange={this.handleCheckAllChange}>
              列展示
            </Checkbox>
            <el-link underline={false} onClick={this.reset}>
              重置
            </el-link>
          </div>
          <div class='divider'></div>
          <div ref='sortDiv'>
            {this.cols.map((column, index) => {
              return (
                <div key={column.label + index}>
                  <div class='drag-item'>
                    <div class='left-item'>
                      <i class='zk-icon el-icon-rank drag-out'></i>
                      <Checkbox
                        value={!column.hideInTable}
                        onChange={() => {
                          this.dispatch('ZkTable', 'change-hide', { hide: !column.hideInTable, index: index })
                          column.hideInTable = !column.hideInTable
                          const num = this.cols.filter((col) => !col.hideInTable).length
                          this.isIndeterminate = num > 0 && num < this.cols.length
                          this.allChecked = num === this.cols.length
                        }}>
                        {column.label}
                      </Checkbox>
                    </div>
                  </div>
                </div>
              )
            })}
          </div>
        </div>
        <Tooltip slot='reference' placement='top' content='列设置'>
          <i class='zk-icon el-icon-setting'></i>
        </Tooltip>
      </Popover>
    )
  },
}
